package com.ruoyi.business.mapper;

import java.util.List;
import com.ruoyi.business.domain.AiUserinfo;

/**
 * 用户信息Mapper接口
 * 
 * @author max
 * @date 2023-05-14
 */
public interface AiUserinfoMapper 
{
    /**
     * 查询用户信息
     * 
     * @param id 用户信息主键
     * @return 用户信息
     */
    public AiUserinfo selectAiUserinfoById(Long id);

    /**
     * 查询用户信息列表
     * 
     * @param aiUserinfo 用户信息
     * @return 用户信息集合
     */
    public List<AiUserinfo> selectAiUserinfoList(AiUserinfo aiUserinfo);

    /**
     * 新增用户信息
     * 
     * @param aiUserinfo 用户信息
     * @return 结果
     */
    public int insertAiUserinfo(AiUserinfo aiUserinfo);

    /**
     * 修改用户信息
     * 
     * @param aiUserinfo 用户信息
     * @return 结果
     */
    public int updateAiUserinfo(AiUserinfo aiUserinfo);

    /**
     * 删除用户信息
     * 
     * @param id 用户信息主键
     * @return 结果
     */
    public int deleteAiUserinfoById(Long id);

    /**
     * 批量删除用户信息
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteAiUserinfoByIds(String[] ids);
}
