package com.ruoyi.web.controller.business.controller;

import java.util.List;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.ResponseBody;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.business.domain.AiUserinfo;
import com.ruoyi.business.service.IAiUserinfoService;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 用户信息Controller
 * 
 * @author max
 * @date 2023-05-14
 */
@Controller
@RequestMapping("/business/userinfo")
public class AiUserinfoController extends BaseController
{
    private String prefix = "business/userinfo";

    @Autowired
    private IAiUserinfoService aiUserinfoService;

    @RequiresPermissions("business:userinfo:view")
    @GetMapping()
    public String userinfo()
    {
        return prefix + "/userinfo";
    }

    /**
     * 查询用户信息列表
     */
    @RequiresPermissions("business:userinfo:list")
    @PostMapping("/list")
    @ResponseBody
    public TableDataInfo list(AiUserinfo aiUserinfo)
    {
        startPage();
        List<AiUserinfo> list = aiUserinfoService.selectAiUserinfoList(aiUserinfo);
        return getDataTable(list);
    }

    /**
     * 导出用户信息列表
     */
    @RequiresPermissions("business:userinfo:export")
    @Log(title = "用户信息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    @ResponseBody
    public AjaxResult export(AiUserinfo aiUserinfo)
    {
        List<AiUserinfo> list = aiUserinfoService.selectAiUserinfoList(aiUserinfo);
        ExcelUtil<AiUserinfo> util = new ExcelUtil<AiUserinfo>(AiUserinfo.class);
        return util.exportExcel(list, "用户信息数据");
    }

    /**
     * 新增用户信息
     */
    @GetMapping("/add")
    public String add()
    {
        return prefix + "/add";
    }

    /**
     * 新增保存用户信息
     */
    @RequiresPermissions("business:userinfo:add")
    @Log(title = "用户信息", businessType = BusinessType.INSERT)
    @PostMapping("/add")
    @ResponseBody
    public AjaxResult addSave(AiUserinfo aiUserinfo)
    {
        return toAjax(aiUserinfoService.insertAiUserinfo(aiUserinfo));
    }

    /**
     * 修改用户信息
     */
    @RequiresPermissions("business:userinfo:edit")
    @GetMapping("/edit/{id}")
    public String edit(@PathVariable("id") Long id, ModelMap mmap)
    {
        AiUserinfo aiUserinfo = aiUserinfoService.selectAiUserinfoById(id);
        mmap.put("aiUserinfo", aiUserinfo);
        return prefix + "/edit";
    }

    /**
     * 修改保存用户信息
     */
    @RequiresPermissions("business:userinfo:edit")
    @Log(title = "用户信息", businessType = BusinessType.UPDATE)
    @PostMapping("/edit")
    @ResponseBody
    public AjaxResult editSave(AiUserinfo aiUserinfo)
    {
        return toAjax(aiUserinfoService.updateAiUserinfo(aiUserinfo));
    }

    /**
     * 删除用户信息
     */
    @RequiresPermissions("business:userinfo:remove")
    @Log(title = "用户信息", businessType = BusinessType.DELETE)
    @PostMapping( "/remove")
    @ResponseBody
    public AjaxResult remove(String ids)
    {
        return toAjax(aiUserinfoService.deleteAiUserinfoByIds(ids));
    }
}
